@@ -27,7 +27,3 @@ def whois_ip(ip):
         parsing = bs(pages.text, "html.parser")
         parse = parsing.find("pre").get_text()
         return parse
-
-if _name_ == "_main_":
-        myIp = whois_ip("180.243.2.185")
-        save("test", myIp)
\ No newline at end of file
